Index: trunk/psphot/src/psphotMarkPSF.c
===================================================================
--- trunk/psphot/src/psphotMarkPSF.c	(revision 4949)
+++ trunk/psphot/src/psphotMarkPSF.c	(revision 5048)
@@ -18,5 +18,5 @@
 // we also reject objects with S/N too low or ChiSquare to high
 
-// any object which meets the criterion is marked as PS_SOURCE_BRIGHTSTAR 
+// any object which meets the criterion is marked as PM_SOURCE_BRIGHTSTAR 
 
 // floor for DS value 
@@ -35,13 +35,13 @@
     // remember: fit does not use saturated pixels (masked)
     if (source->modelPSF->params->data.F32[1] >= SATURATE) {
-	if (source->type == PS_SOURCE_PSFSTAR) {
+	if (source->type == PM_SOURCE_PSFSTAR) {
 	    psLogMsg ("psphot", 3, "PSFSTAR marked SATSTAR\n");
 	}
-	source->type = PS_SOURCE_SATSTAR;
+	source->type = PM_SOURCE_SATSTAR;
 	return (true);
     } 
-    if (source->type == PS_SOURCE_SATSTAR) {
+    if (source->type == PM_SOURCE_SATSTAR) {
 	psLogMsg ("psphot", 4, "SATSTAR marked GOODSTAR (fitted peak below saturation)\n");
-	source->type = PS_SOURCE_GOODSTAR;
+	source->type = PM_SOURCE_GOODSTAR;
     }
 
@@ -57,5 +57,5 @@
     nSy = dSY / hypot (MIN_DS, 1 / (SY * SN));
 
     // assign PS_SOURCE_GOODSTAR to bright objects within PSF region of dparams[]
     keep = TRUE;
     keep &= (fabs(nSx) < shapeNsigma);
@@ -64,10 +64,10 @@
     keep &= (Chi < maxChi);
     if (keep) {
-	if (source->type == PS_SOURCE_PSFSTAR) return (true);
-	source->type = PS_SOURCE_GOODSTAR;
+	if (source->type == PM_SOURCE_PSFSTAR) return (true);
+	source->type = PM_SOURCE_GOODSTAR;
 	return (true);
     }
     
-    if (source->type == PS_SOURCE_PSFSTAR) {
+    if (source->type == PM_SOURCE_PSFSTAR) {
 	psLogMsg ("psphot", 3, "PSFSTAR demoted based on fit quality\n");
     }
@@ -75,5 +75,5 @@
     // object appears to be small, suspected defect
     if ((nSx <= -shapeNsigma) || (nSy <= -shapeNsigma)) {
-	source->type = PS_SOURCE_DEFECT;
+	source->type = PM_SOURCE_DEFECT;
 	return (false);
     }
@@ -81,5 +81,5 @@
     // object appears to be large, suspected galaxy
     if ((nSx >= shapeNsigma) || (nSy >= shapeNsigma)) {
-	source->type = PS_SOURCE_GALAXY;
+	source->type = PM_SOURCE_GALAXY;
 	return (false);
     }
@@ -87,10 +87,10 @@
     // object appears to be extremely faint: what is this?
     if (SN < minSN) {
-	source->type = PS_SOURCE_FAINTSTAR;
+	source->type = PM_SOURCE_FAINTSTAR;
 	return (false);
     }
 
     // these are pooly fitted, probable stars near other stars?
-    source->type = PS_SOURCE_POOR_FIT_PSF;
+    source->type = PM_SOURCE_POOR_FIT_PSF;
     return (false);
 }	
@@ -57,5 +57,5 @@
     nSy = dSY / hypot (MIN_DS, 1 / (SY * SN));
 
-    // assign PS_SOURCE_GOODSTAR to bright objects within PSF region of dparams[]
+    // assign PM_SOURCE_GOODSTAR to bright objects within PSF region of dparams[]
     keep = TRUE;
     keep &= (fabs(nSx) < shapeNsigma);
